@@ -8,7 +8,7 @@ from copy import copy
 
 try:
     import charade
-except ImportError: # For python < 2.6
+except ImportError:  # For python < 2.6
     import chardet as charade
 
 from pysrt.srtexc import Error
@@ -113,6 +113,22 @@ class SubRipFile(UserList, object):
         clone.data = list(clone.data)
         return clone
 
+    def at(self, timestamp=None, **kwargs):
+        """
+        at(timestamp) -> SubRipFile clone
+
+        timestamp argument should be coercible to SubRipFile object.
+
+        A specialization of slice. Return all subtiles visible at the
+        timestamp mark.
+
+        Example:
+            >>> subs.at((0, 0, 20, 0)).shift(seconds=2)
+            >>> subs.at(seconds=20).shift(seconds=2)
+        """
+        time = timestamp or kwargs
+        return self.slice(starts_before=time, ends_after=time)
+
     def shift(self, *args, **kwargs):
         """shift(hours, minutes, seconds, milliseconds, ratio)
 
@@ -141,6 +157,10 @@ class SubRipFile(UserList, object):
         for index, item in enumerate(self):
             item.index = index + 1
 
+    @property
+    def text(self):
+        return u'\n'.join(i.text for i in self)
+
     @classmethod
     def open(cls, path='', encoding=None, error_handling=ERROR_PASS):
         """
@@ -194,10 +214,10 @@ class SubRipFile(UserList, object):
             opened with `codecs.open()` or an array of unicode.
 
         Example:
-            >>> from pysrt import SubRipFile
+            >>> import pysrt
             >>> import codecs
             >>> file = codecs.open('movie.srt', encoding='utf-8')
-            >>> for sub in SubRipFile.stream(file):
+            >>> for sub in pysrt.stream(file):
             ...     sub.text += "\nHello !"
             ...     print unicode(sub)
         """
@@ -286,7 +306,13 @@ class SubRipFile(UserList, object):
 
     @classmethod
     def _detect_encoding(cls, path):
-        report = charade.detect(open(path).read())
+        sample = open(path).read(1024)
+
+        for bom, encoding in BOMS:
+            if sample.startswith(bom):
+                return encoding
+
+        report = charade.detect(sample)
         encoding = report.get('encoding')
         if not encoding:
             return cls.DEFAULT_ENCODING
