@@ -27,19 +27,19 @@ class TestOpen(unittest.TestCase):
         self.invalid_path = os.path.join(self.static_path, 'invalid.srt')
 
     def test_utf8(self):
-        self.assertEquals(len(SubRipFile.open(self.utf8_path)), 1332)
-        self.assertRaises(UnicodeDecodeError, SubRipFile.open,
+        self.assertEquals(len(pysrt.open(self.utf8_path)), 1332)
+        self.assertRaises(UnicodeDecodeError, pysrt.open,
             self.windows_path, encoding='utf_8')
 
     def test_windows1252(self):
-        srt_file = SubRipFile.open(self.windows_path, encoding='windows-1252')
+        srt_file = pysrt.open(self.windows_path, encoding='windows-1252')
         self.assertEquals(len(srt_file), 1332)
         self.assertEquals(srt_file.eol, '\r\n')
-        self.assertRaises(UnicodeDecodeError, SubRipFile.open,
+        self.assertRaises(UnicodeDecodeError, pysrt.open,
             self.utf8_path, encoding='ascii')
 
     def test_error_handling(self):
-        self.assertRaises(pysrt.Error, SubRipFile.open, self.invalid_path,
+        self.assertRaises(pysrt.Error, pysrt.open, self.invalid_path,
             error_handling=SubRipFile.ERROR_RAISE)
 
 
@@ -54,16 +54,16 @@ class TestFromString(unittest.TestCase):
 
     def test_utf8(self):
         unicode_content = codecs.open(self.utf8_path, encoding='utf_8').read()
-        self.assertEquals(len(SubRipFile.from_string(unicode_content)), 1332)
-        self.assertRaises(UnicodeDecodeError, SubRipFile.from_string,
+        self.assertEquals(len(pysrt.from_string(unicode_content)), 1332)
+        self.assertRaises(UnicodeDecodeError, pysrt.from_string,
             open(self.windows_path).read())
 
     def test_windows1252(self):
         srt_string = codecs.open(self.windows_path, encoding='windows-1252').read()
-        srt_file = SubRipFile.from_string(srt_string, encoding='windows-1252', eol='\r\n')
+        srt_file = pysrt.from_string(srt_string, encoding='windows-1252', eol='\r\n')
         self.assertEquals(len(srt_file), 1332)
         self.assertEquals(srt_file.eol, '\r\n')
-        self.assertRaises(UnicodeDecodeError, SubRipFile.open,
+        self.assertRaises(UnicodeDecodeError, pysrt.open,
             self.utf8_path, encoding='ascii')
 
 
@@ -78,13 +78,13 @@ class TestSerialization(unittest.TestCase):
 
     def test_compare_from_string_and_from_path(self):
         unicode_content = codecs.open(self.utf8_path, encoding='utf_8').read()
-        iterator = izip(SubRipFile.open(self.utf8_path),
-            SubRipFile.from_string(unicode_content))
+        iterator = izip(pysrt.open(self.utf8_path),
+            pysrt.from_string(unicode_content))
         for file_item, string_item in iterator:
             self.assertEquals(unicode(file_item), unicode(string_item))
 
     def test_save(self):
-        srt_file = SubRipFile.open(self.windows_path, encoding='windows-1252')
+        srt_file = pysrt.open(self.windows_path, encoding='windows-1252')
         srt_file.save(self.temp_path, eol='\n', encoding='utf-8')
         self.assertEquals(open(self.temp_path, 'rb').read(),
                           open(self.utf8_path, 'rb').read())
@@ -95,7 +95,7 @@ class TestSerialization(unittest.TestCase):
         input_file.read()
         self.assertEquals(input_file.newlines, '\r\n')
 
-        srt_file = SubRipFile.open(self.windows_path, encoding='windows-1252')
+        srt_file = pysrt.open(self.windows_path, encoding='windows-1252')
         srt_file.save(self.temp_path, eol='\n')
 
         output_file = open(self.temp_path, 'rU')
@@ -106,7 +106,7 @@ class TestSerialization(unittest.TestCase):
 class TestSlice(unittest.TestCase):
 
     def setUp(self):
-        self.file = SubRipFile.open(os.path.join(file_path, 'tests', 'static',
+        self.file = pysrt.open(os.path.join(file_path, 'tests', 'static',
             'utf-8.srt'))
 
     def test_slice(self):
@@ -117,6 +117,10 @@ class TestSlice(unittest.TestCase):
         self.assertEquals(len(self.file.slice(starts_after=(1, 2, 3, 4))),
                           459)
 
+    def test_at(self):
+        self.assertEquals(len(self.file.at((0, 0, 31, 0))), 1)
+        self.assertEquals(len(self.file.at(seconds=31)), 1)
+
 
 class TestShifting(unittest.TestCase):
 
@@ -128,6 +132,22 @@ class TestShifting(unittest.TestCase):
         self.assertEquals(srt_file[0].end, (2, 2, 2, 2))
 
 
+class TestText(unittest.TestCase):
+
+    def test_single_item(self):
+        srt_file = SubRipFile([
+            SubRipItem(1, {'seconds': 1}, {'seconds': 2}, u'Hello')
+        ])
+        self.assertEquals(srt_file.text, u'Hello')
+
+    def test_multiple_item(self):
+        srt_file = SubRipFile([
+            SubRipItem(1, {'seconds': 0}, {'seconds': 3}, u'Hello'),
+            SubRipItem(1, {'seconds': 1}, {'seconds': 2}, u'World !')
+        ])
+        self.assertEquals(srt_file.text, u'Hello\nWorld !')
+
+
 class TestDuckTyping(unittest.TestCase):
 
     def setUp(self):
@@ -167,7 +187,7 @@ class TestEOLProperty(unittest.TestCase):
 class TestCleanIndexes(unittest.TestCase):
 
     def setUp(self):
-        self.file = SubRipFile.open(os.path.join(file_path, 'tests', 'static',
+        self.file = pysrt.open(os.path.join(file_path, 'tests', 'static',
             'utf-8.srt'))
 
     def test_clean_indexes(self):
@@ -188,7 +208,7 @@ class TestBOM(unittest.TestCase):
         self.base_path = os.path.join(file_path, 'tests', 'static')
 
     def __test_encoding(self, encoding):
-        srt_file = SubRipFile.open(os.path.join(self.base_path, encoding))
+        srt_file = pysrt.open(os.path.join(self.base_path, encoding))
         self.assertEquals(len(srt_file), 7)
         self.assertEquals(srt_file[0].index, 1)
 
@@ -221,18 +241,18 @@ class TestIntegration(unittest.TestCase):
 
     def test_length(self):
         path = os.path.join(self.base_path, 'capability_tester.srt')
-        file = SubRipFile.open(path)
+        file = pysrt.open(path)
         self.assertEquals(len(file), 37)
 
     def test_empty_file(self):
-        file = SubRipFile.open('/dev/null', error_handling=SubRipFile.ERROR_RAISE)
+        file = pysrt.open('/dev/null', error_handling=SubRipFile.ERROR_RAISE)
         self.assertEquals(len(file), 0)
 
     def test_file_with_empty_items(self):
         path = os.path.join(self.base_path, 'empty.srt')
-        file = SubRipFile.open(path)
+        file = pysrt.open(path)
         self.assertEquals(len(file), 7)
 
     def test_blank_lines(self):
-        items = list(SubRipFile.stream([u'\n'] * 20, error_handling=SubRipFile.ERROR_RAISE))
+        items = list(pysrt.stream([u'\n'] * 20, error_handling=SubRipFile.ERROR_RAISE))
         self.assertEquals(len(items), 0)
