@@ -81,6 +81,7 @@ class TestSerialAndParsing(unittest.TestCase):
         self.vtt = (u'1\n00:01:00,000 --> 00:01:20,000 D:vertical A:start '
                                 'L:12%\nHello world !\n')
         self.dots = u'1\n00:01:00.000 --> 00:01:20.000\nHello world !\n'
+        self.bad_index = u'foo\n00:01:00,000 --> 00:01:20,000\nHello !\n'
 
     def test_serialization(self):
         self.assertEqual(unicode(self.item), self.string)
@@ -115,3 +116,6 @@ class TestSerialAndParsing(unittest.TestCase):
         self.assertRaises(InvalidItem, SubRipItem.from_string, u'1\n'
             '00:01:00,000 -> 00:01:20,000 X1:000 X2:000 '
             'Y1:050 Y2:100\nHello world !\n')
+
+    def test_invalid_index(self):
+        self.assertRaises(InvalidItem, SubRipItem.from_string, self.bad_index)
